EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackages_GetPackage',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'NuGetPackages_Extended,NuGetPackageSymbols',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets information about a package in a feed.'
GO

IF OBJECT_ID('[NuGetPackages_GetPackage]') IS NOT NULL DROP PROCEDURE [NuGetPackages_GetPackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NuGetPackages_GetPackage]
(
	@Feed_Id INT,
	@Package_Id NVARCHAR(255),
	@Version_Text NVARCHAR(50)
)
AS
BEGIN

	SET NOCOUNT ON

	SET @Version_Text = (SELECT CAST((CAST([Major] AS NVARCHAR(10))
                             + (CASE WHEN [Minor] IS NOT NULL THEN '.' + CAST([Minor] AS NVARCHAR(10)) ELSE '' END)
					         + (CASE WHEN [Patch] IS NOT NULL THEN '.' + CAST([Patch] AS NVARCHAR(10)) ELSE '' END)
					         + (CASE WHEN [Build] IS NOT NULL THEN '.' + CAST([Build] AS NVARCHAR(10)) ELSE '' END)
					         + (CASE WHEN [Prerelease] IS NOT NULL THEN '-' + [Prerelease] ELSE '' END)) AS NVARCHAR(50))
                           FROM dbo.ParseNuGetVersion(@Version_Text))

	SELECT *
	  FROM [NuGetPackages_Extended]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Package_Id] = @Package_Id
	   AND [Version_Text] = @Version_Text

	SELECT *
	  FROM [NuGetPackageSymbols]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Package_Id] = @Package_Id
	   AND [Package_Version_Text] = @Version_Text
END
GO

GRANT EXECUTE ON [NuGetPackages_GetPackage] TO [ProGetUser_Role]
GO
